This is an example of things look like if the scale cancellation is not properly done. 
The change was

               &                  + (twopi**3*beta2) * four * log(ev_muR_Q)))
               !&                  + (twopi**3*beta2) * two * log(ev_muR_Q)))

